import subprocess
import dbus
import json


def set_wall(picture_file, use_pywal):
    """
    This method sets a wallpaper
    :param picture_file - The file to use for setting the background
    """
    silent = dict(stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)

    if use_pywal:
        try:
            wal = subprocess.call(["wal", "-i", picture_file, "-q"], **silent)
        except:
            pass

    # implementation for desktop envirorments and window mannagers using feh      for
    # wallpaper management for example:
    # i3
    # openbox
    try:
        feh = subprocess.call(["feh", "--bg-fill", picture_file], **silent)
    except:
        pass

    # gsettings set org.gnome.desktop.background picture-uri 'file:///home/Jo     hnDoe/Pictures/cool_wallpaper.jpg'
    # implementation for gnome desktops such as:
    # ubuntu
    # gnome
    try:
        command = subprocess.call(
            ["gsettings", "set", "org.gnome.desktop.background", "picture-uri", "file://" + picture_file], **silent)
    except:
        pass

    # kde
    try:
        plugin = 'org.kde.image'

        jscript = """
		var allDesktops = desktops();
		print (allDesktops);
		for (i=0;i<allDesktops.length;i++) {
			d = allDesktops[i];
			d.wallpaperPlugin = "%s";
			d.currentConfigGroup = Array("Wallpaper", "%s", "General");
			d.writeConfig("Image", "file://%s")
		}
		"""
        bus = dbus.SessionBus()
        plasma = dbus.Interface(bus.get_object(
            'org.kde.plasmashell', '/PlasmaShell'), dbus_interface='org.kde.PlasmaShell')
        plasma.evaluateScript(jscript % (plugin, plugin, picture_file))

    except:
        pass

    # sway
    try:
        swaymsg = subprocess.call(["swaymsg", "output * bg \"{f}\" fill".format(f=picture_file)], **silent)
    except:
        pass


def get_screen_resolution():
    """
    This method gets the screen resolution using xrandr
    """
    # note, we are using xrandr to get the screen resolution instead of usin     g
    # something like tkinter or wxpython, which provides a cross platform
    # solution to avoid the need for dependecies.

    # xrandr | grep \* | cut -d' ' -f4
    try:
        output = subprocess.Popen("xrandr  | grep \* | cut -d' ' -f4", shell=True, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL).communicate()[0]
        resolution = str(output.split()[0]).replace("b'", '').replace("'", '')
        return resolution
    except:
        pass

    output = subprocess.Popen("swaymsg -t get_outputs", shell=True, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL).communicate()[0]
    tmp = json.loads(output)[0]['current_mode']

    resolution = "{w}x{h}".format(w=tmp['width'], h=tmp['height'])

    return resolution



import sys
import requests
import tempfile
import os
import configparser
import time


def get_wall(resolution="1920x1080", search_term=None, output_path=None):
    """
    This method downloads a random  wallpaper to use from unsplash. The file is 
    saved to a temporary file so it can be taken care of by the operating 
    system.

    :param resolution - the resolution to use for retrieving the wallpaper the  
                        default resolution is 1920x1080
    :return - the picture file retrieved
    """

    base_url = 'https://source.unsplash.com/' + resolution + '/?' + search_term

    r = requests.get(base_url)

    fd, picture_file = tempfile.mkstemp(
        suffix=".jpg", prefix="venus_", dir=output_path)

    with os.fdopen(fd, 'wb') as f:
        # downloading the image to the system
        f.write(r.content)

    return picture_file


def get_config():
    """
    This method gets the configuration for venus

    :return - the config file
    """

    config = configparser.ConfigParser()
    config.read(os.path.join(os.path.expanduser('~'), '.config/venus/config'))

    return config


def main():
    # checking platform for using system specific code
    platform = sys.platform

    if 'linux' in platform:
        from venus.os_tools import linux as system
    elif 'win32' in platform:
        from venus.os_tools import windows as system
    elif 'darwin' in platform:
        from venus.os_tools import darwin as system

    # getting config
    config = get_config()
    search_term_config = config.get('SETTINGS', 'SEARCH_TERMS', fallback='')
    output_path_config = config.get('SETTINGS', 'OUTPUT_PATH', fallback='')
    wait_time_config = config.get('SETTINGS', 'WAIT_TIME', fallback=0)
    use_pywal_config = config.getboolean(
        'SETTINGS', 'USE_PYWAL', fallback=False)

    # default path for empty OUTPUT_PATH setting
    if not output_path_config:
        output_path_config = None

    # loop control var
    run = True

    while run:

        system.set_wall(get_wall(resolution=system.get_screen_resolution(),
                                 search_term=search_term_config,
                                 output_path=output_path_config), use_pywal_config)

        if not wait_time_config:
            run = False
        else:
            time.sleep(int(wait_time_config))


if __name__ == "__main__":
    main()



import subprocess
import ctypes
import os


def set_wall(picture_file, use_pywal):
    """
    This method sets a wallpaper
    :param picture_file - The file to use for setting the background
    """

    if use_pywal:
        try:
            wal = subprocess.call(["wal", "-i", picture_file, "-q"])
        except:
            pass

    # variables for system parameter info for setting the wallaper.

    SPI = 20
    SPIF = 2

    ctypes.windll.user32.SystemParametersInfoW(SPI, 0, picture_file, SPIF)


def get_screen_resolution():
    """
    This method gets the screen resolution using the win32 video controller 
    """
    output = subprocess.Popen("wmic path Win32_VideoController get CurrentHorizontalResolution, CurrentVerticalResolution",
                              shell=True, stdout=subprocess.PIPE).communicate()[0]

    # cleaning up output
    resolution = str(output).replace("CurrentHorizontalResolution", "").replace(
        "CurrentVerticalResolution", "").replace("b'", "").replace("\\n", " ").replace("\\r", " ").split()

    # formationg resolution
    resolution = resolution[0] + "x" + resolution[1]

    return resolution
